pytil (formerly known as Chicken Turtle Util) is a broad scoped Python utility
library.

Links
=====
- `Documentation <http://pytil.readthedocs.io/en/5.0.0/>`_
- `PyPI <https://pypi.python.org/pypi/pytil/>`_
- `GitHub <https://github.com/timdiels/pytil/>`_

